summaryrefslogtreecommitdiffstats
path: root/src/bookmarkselector.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/bookmarkselector.h')
-rw-r--r--src/bookmarkselector.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/bookmarkselector.h b/src/bookmarkselector.h
index d56aec2..05f0b43 100644
--- a/src/bookmarkselector.h
+++ b/src/bookmarkselector.h
@@ -44,18 +44,18 @@ class BookmarkSelector : public URLButton
public:
/**
- * @param tqparent Parent widget where the bookmark selector
+ * @param parent Parent widget where the bookmark selector
* is embedded into.
*/
- BookmarkSelector(URLNavigator* tqparent);
+ BookmarkSelector(URLNavigator* parent);
virtual ~BookmarkSelector();
/**
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
* The bookmark which is equal to the URL or at least is a tqparent URL
* is selected. If there are more than one possible tqparent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/
void updateSelection(const KURL& url);
@@ -44,18 +44,18 @@ class BookmarkSelector : public URLButton
* Updates the selection dependent from the given URL \a url. The
* URL must not match exactly to one of the available bookmarks:
- * The bookmark which is equal to the URL or at least is a tqparent URL
- * is selected. If there are more than one possible tqparent URL candidates,
+ * The bookmark which is equal to the URL or at least is a parent URL
+ * is selected. If there are more than one possible parent URL candidates,
* the bookmark which covers the bigger range of the URL is selected.
*/